export CC=gcc
export CXX=g++

alias grind='~/valgrind-color.sh --tool=memcheck --leak-check=yes --show-reachable=yes --track-origins=yes -v'
alias make='make -j8'
alias ccat='pygmentize -g'
alias nyancat=ccat

cc()
{
    filename=$(basename "$1")
    if [ ${filename##*.} == "c" ]; then
        gcc -std=c99 -pedantic -Wall -Wextra -Werror $@ -o ${filename%.*}
    else
        g++ -Wall -Wextra -Werror -pedantic -std=c++14 $@ -o ${filename%.*}
    fi
}

ccl()
{
    filename=$(basename "$1")
    if [ ${filename##*.} == "c" ]; then
        clang -std=c99 -pedantic -Wall -Wextra -Werror $@ -o ${filename%.*}
    else
        clang++ -Wall -Wextra -Werror -pedantic -std=c++14 $@ -o ${filename%.*}
    fi
}

clean()
{
    if [ -f Makefile ]; then
        make clean
    else
        rm *.o obj/
    fi
    rm *~ .*~ \#*\#
    if [ -d src ]; then
        rm src/*~ src/.*~ src/\#*\#
        rm src/*/*~ src/*/.*~ src/*/\#*\#
    fi
    if [ -d tests ]; then
        rm tests/*~ tests/.*~ tests/\#*\#
        rm tests/*/*~ tests/*/.*~ tests/*/\#*\#
    fi
    rm __pycache__ */__pycache__
    l
}

preload()
{
    LD_PRELOAD=$@
    return $?
}

loadlib()
{
    LD_LIBRARY_PATH="$1" $2
}

h()
{
    u=$(echo "$1" | tr '[:lower:]' '[:upper:]')
    if [ ! -f $1.h ]; then
        echo "#ifndef ${u}_H_" >> $1.h
        echo "# define ${u}_H_" >> $1.h
        echo "" >> $1.h
        echo "" >> $1.h
        echo "" >> $1.h
        echo "#endif /* !${u}_H_ */" >> $1.h
    fi
    if [ ! -f $1.c ]; then
        echo "#include \"$1.h\"" >> $1.c
        echo "" >> $1.c
        echo "" >> $1.c
    fi
}

hh()
{
    if [ ! -f $1.hh ]; then
        echo "#pragma once" >> $1.hh
        echo "" >> $1.hh
    fi
    if [ ! -f $1.cc ]; then
        echo "#include \"$1.hh\"" >> $1.cc
        echo "" >> $1.cc
    fi
}
